@@ -10,7 +10,7 @@ class ModernMTException(Exception):
 
 
 class ModernMT(object):
-    def __init__(self, license_key, platform="modernmt-python", platform_version="1.0.2") -> None:
+    def __init__(self, license_key, platform="modernmt-python", platform_version="1.0.3") -> None:
         self.__base_url = "https://api.modernmt.com"
         self.__headers = {
             "MMT-ApiKey": license_key,
@@ -23,9 +23,23 @@ class ModernMT(object):
     def list_supported_languages(self):
         return self.__send("get", "/translate/languages")
 
-    def translate(self, source, target, q, hints=None, context_vector=None, options=None):
-        multiple_targets = isinstance(q, list)
+    def detect_language(self, q, format=None):
+        data = {"q": q}
+        if format is not None:
+            data["format"] = format
 
+        res = self.__send("get", "/translate/detect", data=data)
+
+        if not isinstance(q, list):
+            return DetectedLanguage(res)
+
+        languages = []
+        for el in res:
+            languages.append(DetectedLanguage(el))
+
+        return languages
+
+    def translate(self, source, target, q, hints=None, context_vector=None, options=None):
         data = {"target": target, "q": q}
         if source is not None:
             data["source"] = source
@@ -50,7 +64,7 @@ class ModernMT(object):
 
         res = self.__send("get", "/translate", data=data)
 
-        if not multiple_targets:
+        if not isinstance(q, list):
             return Translation(res)
 
         translations = []
@@ -219,3 +233,8 @@ class Memory(_Model):
 class ImportJob(_Model):
     def __init__(self, data) -> None:
         super().__init__(data, ["id", "memory", "size", "progress"])
+
+
+class DetectedLanguage(_Model):
+    def __init__(self, data) -> None:
+        super().__init__(data, ["billedCharacters", "detectedLanguage"])
